SolvingMode

#[non_exhaustive]
pub enum SolvingMode { DefaultSolve, ValidateOnly, DetectSomeInfeasibleShipments, TransformAndReturnRequest, UnknownValue(UnknownValue), }
Defines how the solver should handle the request. In all modes but VALIDATE_ONLY, if the request is invalid, you will receive an INVALID_REQUEST error. See max_validation_errors to cap the number of errors returned.

Working with unknown values

This enum is defined as #[non_exhaustive] because Google Cloud may add additional enum variants at any time. Adding new variants is not considered a breaking change. Applications should write their code in anticipation of:

  • New values appearing in future releases of the client library, and
  • New values received dynamically, without application changes.

Please consult the Working with enums section in the user guide for some guidelines.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DefaultSolve

Solve the model. Warnings may be issued in [OptimizeToursResponse.validation_errors][google.cloud.optimization.v1.OptimizeToursResponse.validation_errors].



ValidateOnly

Only validates the model without solving it: populates as many OptimizeToursResponse.validation_errors as possible.



DetectSomeInfeasibleShipments

Only populates OptimizeToursResponse.validation_errors or OptimizeToursResponse.skipped_shipments, and doesn’t actually solve the rest of the request (status and routes are unset in the response). If infeasibilities in injected_solution_constraint routes are detected they are populated in the OptimizeToursResponse.validation_errors field and OptimizeToursResponse.skipped_shipments is left empty.

IMPORTANT: not all infeasible shipments are returned here, but only the ones that are detected as infeasible during preprocessing.



TransformAndReturnRequest

This mode only works if ShipmentModel.objectives is not empty. The request is not solved. It is only validated and filled with costs corresponding to the given objectives. Also see the documentation of ShipmentModel.objectives. The resulting request is returned as OptimizeToursResponse.processed_request.

Experimental: See https://developers.google.com/maps/tt/route-optimization/experimental/objectives/make-request for more details.



UnknownValue(UnknownValue)

If set, the enum was initialized with an unknown value.

Applications can examine the value using SolvingMode::value or SolvingMode::name.

Implementations

Source

impl SolvingMode

pub fn value(&self) -> Option<i32>

Gets the enum value.

Returns None if the enum contains an unknown value deserialized from the string representation of enums.

pub fn name(&self) -> Option<&str>

Gets the enum value as a string.

Returns None if the enum contains an unknown value deserialized from the integer representation of enums.