#[non_exhaustive]pub struct Objective {
pub type: Option<Type>,
pub weight: Option<f64>,
/* private fields */
}Expand description
Objectives replace the cost model completely, and are therefore incompatible with pre-existing costs. Each objective maps to a number of pre-defined costs for, e.g., vehicles, shipments or transition attributes.
Experimental: See https://developers.google.com/maps/tt/route-optimization/experimental/objectives/make-request for more details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<Type>The type of the objective.
weight: Option<f64>How much this objective should count relatively to the others. This can be any non-negative number, weights do not have to sum to 1. Weights default to 1.0.
Implementations
Sourceimpl Objective
impl Objective
Sourcepub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_type<T>(self, v: Option<T>) -> Self
Sets or clears the value of r#type.
Example
ⓘ
use google_maps_routeoptimization_v1::model::shipment_model::objective::Type;
let x0 = Objective::new().set_or_clear_type(Some(Type::MinDistance));
let x1 = Objective::new().set_or_clear_type(Some(Type::MinWorkingTime));
let x2 = Objective::new().set_or_clear_type(Some(Type::MinTravelTime));
let x_none = Objective::new().set_or_clear_type(None::<Type>);Sourcepub fn set_weight<T>(self, v: T) -> Self
pub fn set_weight<T>(self, v: T) -> Self