OptimizeToursResponse

Struct OptimizeToursResponse 

#[non_exhaustive]
pub struct OptimizeToursResponse { pub routes: Vec<ShipmentRoute>, pub request_label: String, pub skipped_shipments: Vec<SkippedShipment>, pub validation_errors: Vec<OptimizeToursValidationError>, pub processed_request: Option<OptimizeToursRequest>, pub metrics: Option<Metrics>, /* private fields */ }
Response after solving a tour optimization problem containing the routes followed by each vehicle, the shipments which have been skipped and the overall cost of the solution.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
routes: Vec<ShipmentRoute>

Routes computed for each vehicle; the i-th route corresponds to the i-th vehicle in the model.

request_label: String

Copy of the OptimizeToursRequest.label, if a label was specified in the request.

skipped_shipments: Vec<SkippedShipment>

The list of all shipments skipped.

validation_errors: Vec<OptimizeToursValidationError>

List of all the validation errors that we were able to detect independently. See the “MULTIPLE ERRORS” explanation for the OptimizeToursValidationError message. Instead of errors, this will include warnings in the case solving_mode is DEFAULT_SOLVE.

processed_request: Option<OptimizeToursRequest>

In some cases we modify the incoming request before solving it, i.e. adding costs. If solving_mode == TRANSFORM_AND_RETURN_REQUEST, the modified request is returned here.

Experimental: See https://developers.google.com/maps/tt/route-optimization/experimental/objectives/make-request for more details.

metrics: Option<Metrics>

Duration, distance and usage metrics for this solution.

Implementations

Source

impl OptimizeToursResponse

pub fn new() -> Self

Creates a new default instance.

pub fn set_routes<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ShipmentRoute>,

Sets the value of routes.

Example
use google_maps_routeoptimization_v1::model::ShipmentRoute;
let x = OptimizeToursResponse::new()
    .set_routes([
        ShipmentRoute::default()/* use setters */,
        ShipmentRoute::default()/* use (different) setters */,
    ]);
pub fn set_request_label<T: Into<String>>(self, v: T) -> Self

Sets the value of request_label.

Example
let x = OptimizeToursResponse::new().set_request_label("example");
pub fn set_skipped_shipments<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<SkippedShipment>,

Sets the value of skipped_shipments.

Example
use google_maps_routeoptimization_v1::model::SkippedShipment;
let x = OptimizeToursResponse::new()
    .set_skipped_shipments([
        SkippedShipment::default()/* use setters */,
        SkippedShipment::default()/* use (different) setters */,
    ]);
pub fn set_validation_errors<T, V>(self, v: T) -> Self

Sets the value of validation_errors.

Example
use google_maps_routeoptimization_v1::model::OptimizeToursValidationError;
let x = OptimizeToursResponse::new()
    .set_validation_errors([
        OptimizeToursValidationError::default()/* use setters */,
        OptimizeToursValidationError::default()/* use (different) setters */,
    ]);
pub fn set_processed_request<T>(self, v: T) -> Self

Sets the value of processed_request.

Example
use google_maps_routeoptimization_v1::model::OptimizeToursRequest;
let x = OptimizeToursResponse::new().set_processed_request(OptimizeToursRequest::default()/* use setters */);
pub fn set_or_clear_processed_request<T>(self, v: Option<T>) -> Self

Sets or clears the value of processed_request.

Example
use google_maps_routeoptimization_v1::model::OptimizeToursRequest;
let x = OptimizeToursResponse::new().set_or_clear_processed_request(Some(OptimizeToursRequest::default()/* use setters */));
let x = OptimizeToursResponse::new().set_or_clear_processed_request(None::<OptimizeToursRequest>);
pub fn set_metrics<T>(self, v: T) -> Self
where T: Into<Metrics>,

Sets the value of metrics.

Example
use google_maps_routeoptimization_v1::model::optimize_tours_response::Metrics;
let x = OptimizeToursResponse::new().set_metrics(Metrics::default()/* use setters */);
pub fn set_or_clear_metrics<T>(self, v: Option<T>) -> Self
where T: Into<Metrics>,

Sets or clears the value of metrics.

Example
use google_maps_routeoptimization_v1::model::optimize_tours_response::Metrics;
let x = OptimizeToursResponse::new().set_or_clear_metrics(Some(Metrics::default()/* use setters */));
let x = OptimizeToursResponse::new().set_or_clear_metrics(None::<Metrics>);