#[non_exhaustive]pub struct Uri {
pub uri: String,
/* private fields */
}Expand description
A Universal Resource Identifier that points to a resource that can be read and written by the Route Optimization API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringThe URI of the resource. The resource may not yet exist.
The contents of the resource are encoded as either JSON
or textproto. Only Google Cloud Storage resources are supported. If the
resource is encoded as JSON, the resource name must be suffixed with
.json. If the resource is encoded as textproto, the resource name must
be suffixed with .txtpb. For example, a Google Cloud Storage URI to
a JSON encoded file might look like: gs://bucket/path/input/object.json.
Implementations