VehicleFullness

Struct VehicleFullness 

#[non_exhaustive]
pub struct VehicleFullness { pub max_fullness: Option<f64>, pub distance: Option<f64>, pub travel_duration: Option<f64>, pub active_duration: Option<f64>, pub max_load: Option<f64>, pub active_span: Option<f64>, /* private fields */ }
VehicleFullness is a metric which computes how full a vehicle is. Each VehicleFullness field is between 0 and 1, computed as the ratio between a capped metric field (e.g. AggregatedMetrics.travel_distance_meters) and its related vehicle limit (e.g. Vehicle.route_distance_limit), if it exists. Otherwise the fullness ratio stays unset. If the limit is 0, the field is set to 1. Note: when a route is subject to traffic infeasibilities, some raw fullness ratios might exceed 1.0, e.g. the vehicle might exceed its distance limit. In these cases, we cap the fullness values at 1.0.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
max_fullness: Option<f64>

Maximum of all other fields in this message.

distance: Option<f64>

The ratio between AggregatedMetrics.travel_distance_meters and Vehicle.route_distance_limit. If Vehicle.route_distance_limit is unset, this field will be unset.

travel_duration: Option<f64>

The ratio between [AggregatedMetrics.travel_duration_seconds][] and Vehicle.travel_duration_limit. If Vehicle.travel_duration_limit is unset, this field will be unset.

active_duration: Option<f64>

The ratio between [AggregatedMetrics.total_duration_seconds][] and Vehicle.route_duration_limit. If Vehicle.route_duration_limit is unset, this field will be unset.

max_load: Option<f64>

The maximum ratio among all types of [AggregatedMetrics.max_load][] and their respective Vehicle.load_limits. If all Vehicle.load_limits fields are unset, this field will be unset.

active_span: Option<f64>

The ratio (vehicle_end_time - vehicle_start_time) / (latest_vehicle_end_time - earliest_vehicle_start_time) for a given vehicle. If the denominator is not present, it uses ([ShipmentModel.global_end_time] - [ShipmentModel.global_start_time]) instead.

Implementations

Source

impl VehicleFullness

pub fn new() -> Self

Creates a new default instance.

pub fn set_max_fullness<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of max_fullness.

Example
let x = VehicleFullness::new().set_max_fullness(42.0);
pub fn set_or_clear_max_fullness<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of max_fullness.

Example
let x = VehicleFullness::new().set_or_clear_max_fullness(Some(42.0));
let x = VehicleFullness::new().set_or_clear_max_fullness(None::<f32>);
pub fn set_distance<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of distance.

Example
let x = VehicleFullness::new().set_distance(42.0);
pub fn set_or_clear_distance<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of distance.

Example
let x = VehicleFullness::new().set_or_clear_distance(Some(42.0));
let x = VehicleFullness::new().set_or_clear_distance(None::<f32>);
pub fn set_travel_duration<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of travel_duration.

Example
let x = VehicleFullness::new().set_travel_duration(42.0);
pub fn set_or_clear_travel_duration<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of travel_duration.

Example
let x = VehicleFullness::new().set_or_clear_travel_duration(Some(42.0));
let x = VehicleFullness::new().set_or_clear_travel_duration(None::<f32>);
pub fn set_active_duration<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of active_duration.

Example
let x = VehicleFullness::new().set_active_duration(42.0);
pub fn set_or_clear_active_duration<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of active_duration.

Example
let x = VehicleFullness::new().set_or_clear_active_duration(Some(42.0));
let x = VehicleFullness::new().set_or_clear_active_duration(None::<f32>);
pub fn set_max_load<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of max_load.

Example
let x = VehicleFullness::new().set_max_load(42.0);
pub fn set_or_clear_max_load<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of max_load.

Example
let x = VehicleFullness::new().set_or_clear_max_load(Some(42.0));
let x = VehicleFullness::new().set_or_clear_max_load(None::<f32>);
pub fn set_active_span<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of active_span.

Example
let x = VehicleFullness::new().set_active_span(42.0);
pub fn set_or_clear_active_span<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of active_span.

Example
let x = VehicleFullness::new().set_or_clear_active_span(Some(42.0));
let x = VehicleFullness::new().set_or_clear_active_span(None::<f32>);